
interface AnimationOptions {
  keyframes: Keyframe[];
  options?: KeyframeAnimationOptions;
}
type AnimationHookResult = {
  startAnimation: (element: HTMLElement | null, options: AnimationOptions) => void;
  pauseAnimation: (element: HTMLElement | null) => void;
  cancelAnimation: (element: HTMLElement | null) => void;
  playAnimation: (element: HTMLElement | null) => void;
};

export const useAnimation = (): AnimationHookResult => {
  const startAnimation = (element: HTMLElement | null, options: AnimationOptions) => {
    if (element) {
      element.animate(options.keyframes, options.options);

    }
  };


  const pauseAnimation = (element: HTMLElement | null) => {
    if (element) {
      element.getAnimations().forEach((animation) => {
        if (animation.playState === 'paused') {
          animation.play();
        } else {
          animation.pause();
        }
      });
    }
  };

  const playAnimation = (element: HTMLElement | null) => {
    if (element) {
      element.getAnimations().forEach((animation) => {
        if (animation.playState === 'paused') {
          animation.play();
        }
      });
    }
  }

  const cancelAnimation = (element: HTMLElement | null) => {
    if (element) {
      element.getAnimations().forEach((animation) => animation.cancel());
    }
  };

  return { startAnimation, pauseAnimation, cancelAnimation, playAnimation };
}