import { useState, useEffect } from 'react';

type Theme = 'light' | 'dark' | 'system';

export const useDarkMode = (initialValue: Theme = 'system'): [Theme, () => void] => {
  const [theme, setTheme] = useState<Theme>(initialValue);

  const setDarkMode = () => {
    const prefersDarkMode = window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches;
    if (theme === 'system') {
      setTheme(prefersDarkMode ? 'dark' : 'light');
    } else {
      setTheme(theme === 'light' ? 'dark' : 'light');
    }
  };

  useEffect(() => {
    const prefersDarkMode = window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches;
    if (initialValue === 'system') {
      setTheme(prefersDarkMode ? 'dark' : 'light');
    } else {
      setTheme(initialValue);
    }
  }, [initialValue]);

  return [theme, setDarkMode];
}