
import { useState, useEffect } from 'react'

export const useThrottle = <T>(value: T, limit: number) => {
  const [throttledValue, setThrottledValue] = useState(value);
  const [lastExecTime, setLastExecTime] = useState(Date.now());


  useEffect(() => {
    const now = Date.now();
    if (now - lastExecTime > limit) {
      setThrottledValue(value);
      setLastExecTime(now);
    }
  }, [value, limit, lastExecTime]);

  return throttledValue;
}